# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.math_element import MathElement

class GroupingCharacterElement(MathElement):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'base': 'MathElement',
        'character': 'str',
        'position': 'str',
        'vertical_justification': 'str'
    }

    attribute_map = {
        'type': 'type',
        'base': 'base',
        'character': 'character',
        'position': 'position',
        'vertical_justification': 'verticalJustification'
    }

    type_determiners = {
        'type': 'GroupingCharacter',
    }

    def __init__(self, type='GroupingCharacter', base=None, character=None, position=None, vertical_justification=None):  # noqa: E501
        """GroupingCharacterElement - a model defined in Swagger"""  # noqa: E501
        super(GroupingCharacterElement, self).__init__(type)

        self._base = None
        self._character = None
        self._position = None
        self._vertical_justification = None
        self.type = 'GroupingCharacter'

        if base is not None:
            self.base = base
        if character is not None:
            self.character = character
        if position is not None:
            self.position = position
        if vertical_justification is not None:
            self.vertical_justification = vertical_justification

    @property
    def base(self):
        """Gets the base of this GroupingCharacterElement.  # noqa: E501

        Base  # noqa: E501

        :return: The base of this GroupingCharacterElement.  # noqa: E501
        :rtype: MathElement
        """
        return self._base

    @base.setter
    def base(self, base):
        """Sets the base of this GroupingCharacterElement.

        Base  # noqa: E501

        :param base: The base of this GroupingCharacterElement.  # noqa: E501
        :type: MathElement
        """
        self._base = base

    @property
    def character(self):
        """Gets the character of this GroupingCharacterElement.  # noqa: E501

        Grouping character  # noqa: E501

        :return: The character of this GroupingCharacterElement.  # noqa: E501
        :rtype: str
        """
        return self._character

    @character.setter
    def character(self, character):
        """Sets the character of this GroupingCharacterElement.

        Grouping character  # noqa: E501

        :param character: The character of this GroupingCharacterElement.  # noqa: E501
        :type: str
        """
        self._character = character

    @property
    def position(self):
        """Gets the position of this GroupingCharacterElement.  # noqa: E501

        Position of grouping character.  # noqa: E501

        :return: The position of this GroupingCharacterElement.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this GroupingCharacterElement.

        Position of grouping character.  # noqa: E501

        :param position: The position of this GroupingCharacterElement.  # noqa: E501
        :type: str
        """
        if position is not None:
            allowed_values = ["NotDefined", "Top", "Bottom"]  # noqa: E501
            if position.isdigit():
                int_position = int(position)
                if int_position < 0 or int_position >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `position` ({0}), must be one of {1}"  # noqa: E501
                        .format(position, allowed_values)
                    )
                self._position = allowed_values[int_position]
                return
            if position not in allowed_values:
                raise ValueError(
                    "Invalid value for `position` ({0}), must be one of {1}"  # noqa: E501
                    .format(position, allowed_values)
                )
        self._position = position

    @property
    def vertical_justification(self):
        """Gets the vertical_justification of this GroupingCharacterElement.  # noqa: E501

        Vertical justification of group character.  # noqa: E501

        :return: The vertical_justification of this GroupingCharacterElement.  # noqa: E501
        :rtype: str
        """
        return self._vertical_justification

    @vertical_justification.setter
    def vertical_justification(self, vertical_justification):
        """Sets the vertical_justification of this GroupingCharacterElement.

        Vertical justification of group character.  # noqa: E501

        :param vertical_justification: The vertical_justification of this GroupingCharacterElement.  # noqa: E501
        :type: str
        """
        if vertical_justification is not None:
            allowed_values = ["NotDefined", "Top", "Bottom"]  # noqa: E501
            if vertical_justification.isdigit():
                int_vertical_justification = int(vertical_justification)
                if int_vertical_justification < 0 or int_vertical_justification >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `vertical_justification` ({0}), must be one of {1}"  # noqa: E501
                        .format(vertical_justification, allowed_values)
                    )
                self._vertical_justification = allowed_values[int_vertical_justification]
                return
            if vertical_justification not in allowed_values:
                raise ValueError(
                    "Invalid value for `vertical_justification` ({0}), must be one of {1}"  # noqa: E501
                    .format(vertical_justification, allowed_values)
                )
        self._vertical_justification = vertical_justification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupingCharacterElement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six

from asposeslidescloud.models.path_segment import PathSegment

class CubicBezierToPathSegment(PathSegment):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'x1': 'float',
        'y1': 'float',
        'x2': 'float',
        'y2': 'float',
        'x3': 'float',
        'y3': 'float'
    }

    attribute_map = {
        'type': 'type',
        'x1': 'x1',
        'y1': 'y1',
        'x2': 'x2',
        'y2': 'y2',
        'x3': 'x3',
        'y3': 'y3'
    }

    type_determiners = {
        'type': 'CubicBezierTo',
    }

    def __init__(self, type='CubicBezierTo', x1=None, y1=None, x2=None, y2=None, x3=None, y3=None):  # noqa: E501
        """CubicBezierToPathSegment - a model defined in Swagger"""  # noqa: E501
        super(CubicBezierToPathSegment, self).__init__(type)

        self._x1 = None
        self._y1 = None
        self._x2 = None
        self._y2 = None
        self._x3 = None
        self._y3 = None
        self.type = 'CubicBezierTo'

        self.x1 = x1
        self.y1 = y1
        self.x2 = x2
        self.y2 = y2
        self.x3 = x3
        self.y3 = y3

    @property
    def x1(self):
        """Gets the x1 of this CubicBezierToPathSegment.  # noqa: E501

        X coordinate of the first direction point  # noqa: E501

        :return: The x1 of this CubicBezierToPathSegment.  # noqa: E501
        :rtype: float
        """
        return self._x1

    @x1.setter
    def x1(self, x1):
        """Sets the x1 of this CubicBezierToPathSegment.

        X coordinate of the first direction point  # noqa: E501

        :param x1: The x1 of this CubicBezierToPathSegment.  # noqa: E501
        :type: float
        """
        self._x1 = x1

    @property
    def y1(self):
        """Gets the y1 of this CubicBezierToPathSegment.  # noqa: E501

        Y coordinate of the first direction point  # noqa: E501

        :return: The y1 of this CubicBezierToPathSegment.  # noqa: E501
        :rtype: float
        """
        return self._y1

    @y1.setter
    def y1(self, y1):
        """Sets the y1 of this CubicBezierToPathSegment.

        Y coordinate of the first direction point  # noqa: E501

        :param y1: The y1 of this CubicBezierToPathSegment.  # noqa: E501
        :type: float
        """
        self._y1 = y1

    @property
    def x2(self):
        """Gets the x2 of this CubicBezierToPathSegment.  # noqa: E501

        X coordinate of the second direction point  # noqa: E501

        :return: The x2 of this CubicBezierToPathSegment.  # noqa: E501
        :rtype: float
        """
        return self._x2

    @x2.setter
    def x2(self, x2):
        """Sets the x2 of this CubicBezierToPathSegment.

        X coordinate of the second direction point  # noqa: E501

        :param x2: The x2 of this CubicBezierToPathSegment.  # noqa: E501
        :type: float
        """
        self._x2 = x2

    @property
    def y2(self):
        """Gets the y2 of this CubicBezierToPathSegment.  # noqa: E501

        Y coordinate of the second direction point  # noqa: E501

        :return: The y2 of this CubicBezierToPathSegment.  # noqa: E501
        :rtype: float
        """
        return self._y2

    @y2.setter
    def y2(self, y2):
        """Sets the y2 of this CubicBezierToPathSegment.

        Y coordinate of the second direction point  # noqa: E501

        :param y2: The y2 of this CubicBezierToPathSegment.  # noqa: E501
        :type: float
        """
        self._y2 = y2

    @property
    def x3(self):
        """Gets the x3 of this CubicBezierToPathSegment.  # noqa: E501

        X coordinate of end point  # noqa: E501

        :return: The x3 of this CubicBezierToPathSegment.  # noqa: E501
        :rtype: float
        """
        return self._x3

    @x3.setter
    def x3(self, x3):
        """Sets the x3 of this CubicBezierToPathSegment.

        X coordinate of end point  # noqa: E501

        :param x3: The x3 of this CubicBezierToPathSegment.  # noqa: E501
        :type: float
        """
        self._x3 = x3

    @property
    def y3(self):
        """Gets the y3 of this CubicBezierToPathSegment.  # noqa: E501

        Y coordinate of end point  # noqa: E501

        :return: The y3 of this CubicBezierToPathSegment.  # noqa: E501
        :rtype: float
        """
        return self._y3

    @y3.setter
    def y3(self, y3):
        """Sets the y3 of this CubicBezierToPathSegment.

        Y coordinate of end point  # noqa: E501

        :param y3: The y3 of this CubicBezierToPathSegment.  # noqa: E501
        :type: float
        """
        self._y3 = y3

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CubicBezierToPathSegment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# -----------------------------------------------------------------------------------
# <copyright company="Aspose">
#   Copyright (c) 2018 Aspose.Slides for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

import pprint
import re  # noqa: F401

import six


class LightRig(object):


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'direction': 'str',
        'light_type': 'str',
        'x_rotation': 'float',
        'y_rotation': 'float',
        'z_rotation': 'float'
    }

    attribute_map = {
        'direction': 'direction',
        'light_type': 'lightType',
        'x_rotation': 'xRotation',
        'y_rotation': 'yRotation',
        'z_rotation': 'zRotation'
    }

    type_determiners = {
    }

    def __init__(self, direction=None, light_type=None, x_rotation=None, y_rotation=None, z_rotation=None):  # noqa: E501
        """LightRig - a model defined in Swagger"""  # noqa: E501

        self._direction = None
        self._light_type = None
        self._x_rotation = None
        self._y_rotation = None
        self._z_rotation = None

        if direction is not None:
            self.direction = direction
        if light_type is not None:
            self.light_type = light_type
        if x_rotation is not None:
            self.x_rotation = x_rotation
        if y_rotation is not None:
            self.y_rotation = y_rotation
        if z_rotation is not None:
            self.z_rotation = z_rotation

    @property
    def direction(self):
        """Gets the direction of this LightRig.  # noqa: E501

        Light direction  # noqa: E501

        :return: The direction of this LightRig.  # noqa: E501
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this LightRig.

        Light direction  # noqa: E501

        :param direction: The direction of this LightRig.  # noqa: E501
        :type: str
        """
        if direction is not None:
            allowed_values = ["TopLeft", "Top", "TopRight", "Right", "BottomRight", "Bottom", "BottomLeft", "Left", "NotDefined"]  # noqa: E501
            if direction.isdigit():
                int_direction = int(direction)
                if int_direction < 0 or int_direction >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `direction` ({0}), must be one of {1}"  # noqa: E501
                        .format(direction, allowed_values)
                    )
                self._direction = allowed_values[int_direction]
                return
            if direction not in allowed_values:
                raise ValueError(
                    "Invalid value for `direction` ({0}), must be one of {1}"  # noqa: E501
                    .format(direction, allowed_values)
                )
        self._direction = direction

    @property
    def light_type(self):
        """Gets the light_type of this LightRig.  # noqa: E501

        Light type  # noqa: E501

        :return: The light_type of this LightRig.  # noqa: E501
        :rtype: str
        """
        return self._light_type

    @light_type.setter
    def light_type(self, light_type):
        """Sets the light_type of this LightRig.

        Light type  # noqa: E501

        :param light_type: The light_type of this LightRig.  # noqa: E501
        :type: str
        """
        if light_type is not None:
            allowed_values = ["Balanced", "BrightRoom", "Chilly", "Contrasting", "Flat", "Flood", "Freezing", "Glow", "Harsh", "LegacyFlat1", "LegacyFlat2", "LegacyFlat3", "LegacyFlat4", "LegacyHarsh1", "LegacyHarsh2", "LegacyHarsh3", "LegacyHarsh4", "LegacyNormal1", "LegacyNormal2", "LegacyNormal3", "LegacyNormal4", "Morning", "Soft", "Sunrise", "Sunset", "ThreePt", "TwoPt", "NotDefined"]  # noqa: E501
            if light_type.isdigit():
                int_light_type = int(light_type)
                if int_light_type < 0 or int_light_type >= len(allowed_values):
                    raise ValueError(
                        "Invalid value for `light_type` ({0}), must be one of {1}"  # noqa: E501
                        .format(light_type, allowed_values)
                    )
                self._light_type = allowed_values[int_light_type]
                return
            if light_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `light_type` ({0}), must be one of {1}"  # noqa: E501
                    .format(light_type, allowed_values)
                )
        self._light_type = light_type

    @property
    def x_rotation(self):
        """Gets the x_rotation of this LightRig.  # noqa: E501

        XRotation  # noqa: E501

        :return: The x_rotation of this LightRig.  # noqa: E501
        :rtype: float
        """
        return self._x_rotation

    @x_rotation.setter
    def x_rotation(self, x_rotation):
        """Sets the x_rotation of this LightRig.

        XRotation  # noqa: E501

        :param x_rotation: The x_rotation of this LightRig.  # noqa: E501
        :type: float
        """
        self._x_rotation = x_rotation

    @property
    def y_rotation(self):
        """Gets the y_rotation of this LightRig.  # noqa: E501

        YRotation  # noqa: E501

        :return: The y_rotation of this LightRig.  # noqa: E501
        :rtype: float
        """
        return self._y_rotation

    @y_rotation.setter
    def y_rotation(self, y_rotation):
        """Sets the y_rotation of this LightRig.

        YRotation  # noqa: E501

        :param y_rotation: The y_rotation of this LightRig.  # noqa: E501
        :type: float
        """
        self._y_rotation = y_rotation

    @property
    def z_rotation(self):
        """Gets the z_rotation of this LightRig.  # noqa: E501

        ZRotation  # noqa: E501

        :return: The z_rotation of this LightRig.  # noqa: E501
        :rtype: float
        """
        return self._z_rotation

    @z_rotation.setter
    def z_rotation(self, z_rotation):
        """Sets the z_rotation of this LightRig.

        ZRotation  # noqa: E501

        :param z_rotation: The z_rotation of this LightRig.  # noqa: E501
        :type: float
        """
        self._z_rotation = z_rotation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LightRig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
